==> openshift-model-machineconfiguration-7.2.0-sources.jar: io/fabric8/openshift/api/model/machineconfiguration/v1alpha1/MachineConfigNodeStatusPinnedImageSetBuilder.java <==
package io.fabric8.openshift.api.model.machineconfiguration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class MachineConfigNodeStatusPinnedImageSetBuilder extends MachineConfigNodeStatusPinnedImageSetFluent<MachineConfigNodeStatusPinnedImageSetBuilder> implements VisitableBuilder<MachineConfigNodeStatusPinnedImageSet,MachineConfigNodeStatusPinnedImageSetBuilder>{
  public MachineConfigNodeStatusPinnedImageSetBuilder() {
    this(new MachineConfigNodeStatusPinnedImageSet());
  }
  
  public MachineConfigNodeStatusPinnedImageSetBuilder(MachineConfigNodeStatusPinnedImageSetFluent<?> fluent) {
    this(fluent, new MachineConfigNodeStatusPinnedImageSet());
  }
  
  public MachineConfigNodeStatusPinnedImageSetBuilder(MachineConfigNodeStatusPinnedImageSetFluent<?> fluent,MachineConfigNodeStatusPinnedImageSet instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public MachineConfigNodeStatusPinnedImageSetBuilder(MachineConfigNodeStatusPinnedImageSet instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  MachineConfigNodeStatusPinnedImageSetFluent<?> fluent;
  
  public MachineConfigNodeStatusPinnedImageSet build() {
    MachineConfigNodeStatusPinnedImageSet buildable = new MachineConfigNodeStatusPinnedImageSet(fluent.getCurrentGeneration(),fluent.getDesiredGeneration(),fluent.getLastFailedGeneration(),fluent.getLastFailedGenerationErrors(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}

==> openshift-model-machineconfiguration-7.4.0-sources.jar: io/fabric8/openshift/api/model/machineconfiguration/v1alpha1/MachineConfigNodeStatusPinnedImageSetBuilder.java <==
package io.fabric8.openshift.api.model.machineconfiguration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class MachineConfigNodeStatusPinnedImageSetBuilder extends MachineConfigNodeStatusPinnedImageSetFluent<MachineConfigNodeStatusPinnedImageSetBuilder> implements VisitableBuilder<MachineConfigNodeStatusPinnedImageSet,MachineConfigNodeStatusPinnedImageSetBuilder>{
  public MachineConfigNodeStatusPinnedImageSetBuilder() {
    this(new MachineConfigNodeStatusPinnedImageSet());
  }
  
  public MachineConfigNodeStatusPinnedImageSetBuilder(MachineConfigNodeStatusPinnedImageSetFluent<?> fluent) {
    this(fluent, new MachineConfigNodeStatusPinnedImageSet());
  }
  
  public MachineConfigNodeStatusPinnedImageSetBuilder(MachineConfigNodeStatusPinnedImageSetFluent<?> fluent,MachineConfigNodeStatusPinnedImageSet instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public MachineConfigNodeStatusPinnedImageSetBuilder(MachineConfigNodeStatusPinnedImageSet instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  MachineConfigNodeStatusPinnedImageSetFluent<?> fluent;
  
  public MachineConfigNodeStatusPinnedImageSet build() {
    MachineConfigNodeStatusPinnedImageSet buildable = new MachineConfigNodeStatusPinnedImageSet(fluent.getCurrentGeneration(),fluent.getDesiredGeneration(),fluent.getLastFailedGeneration(),fluent.getLastFailedGenerationError(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
